@@ -5,7 +5,7 @@ from time import sleep
 import http.server
 import ssl
 from unittest.mock import AsyncMock
-from datetime import datetime, timedelta
+from datetime import datetime, timedelta, UTC
 
 import httpx
 import pytest
@@ -68,52 +68,48 @@ async def test_ssl_scanner():
         await module.attack(request)
 
         persister.add_payload.assert_any_call(
-            request_id=-1,
             payload_type="additional",
             module="ssl",
             category="TLS/SSL misconfigurations",
             level=INFO_LEVEL,
             request=request,
-            parameter='',
+            parameter=None,
             wstg=["WSTG-CRYP-01"],
             info="Certificate subject: yolo.com",
             response=None
         )
 
         persister.add_payload.assert_any_call(
-            request_id=-1,
             payload_type="vulnerability",
             module="ssl",
             category="TLS/SSL misconfigurations",
             level=CRITICAL_LEVEL,
             request=request,
-            parameter='',
+            parameter=None,
             wstg=["WSTG-CRYP-01"],
             info="Requested hostname doesn't match those in the certificate",
             response=None
         )
 
         persister.add_payload.assert_any_call(
-            request_id=-1,
             payload_type="vulnerability",
             module="ssl",
             category="TLS/SSL misconfigurations",
             level=HIGH_LEVEL,
             request=request,
-            parameter='',
+            parameter=None,
             wstg=["WSTG-CRYP-01"],
             info="Strict Transport Security (HSTS) is not set",
             response=None
         )
 
         persister.add_payload.assert_any_call(
-            request_id=-1,
             payload_type="vulnerability",
             module="ssl",
             category="TLS/SSL misconfigurations",
             level=MEDIUM_LEVEL,
             request=request,
-            parameter='',
+            parameter=None,
             wstg=["WSTG-CRYP-01"],
             info="Self-signed certificate detected: The certificate is not signed by a trusted Certificate Authority",
             response=None
@@ -161,9 +157,9 @@ def generate_cert(include_organization_name: bool = True, include_ocsp_must_stap
     ).serial_number(
         x509.random_serial_number()
     ).not_valid_before(
-        datetime.utcnow()
+        datetime.now(UTC)
     ).not_valid_after(
-        datetime.utcnow() + timedelta(days=10)
+        datetime.now(UTC) + timedelta(days=10)
     ).add_extension(
         x509.SubjectAlternativeName([x509.DNSName(u"localhost")]),
         critical=False,
@@ -216,6 +212,7 @@ async def test_process_vulnerabilities():
     results = [info async for info in process_vulnerabilities(xml_file)]
     assert [
         (4, 'Server is vulnerable to Heartbleed attack via TLSv1.0'),
+        (4, 'Server is vulnerable to CRIME attack (compression is supported)'),
         (3, 'Server honors client-initiated renegotiations (vulnerable to DoS attacks)')
     ] == results
 
